Tag

Enum Tag 

pub enum Tag {
Show 108 variants A, Abbr, Address, Article, Aside, Audio, B, Base, Bdi, Bdo, Blockquote, Body, Br, Button, Caption, Cite, Code, Col, Colgroup, Data, Datalist, Dd, Del, Details, Dfn, Dialog, Div, Dl, Dt, Em, Embed, Fieldset, Figcaption, Figure, Footer, Form, H1, H2, H3, H4, H5, H6, Head, Header, Hr, Html, I, Iframe, Img, Input, Ins, Kbd, Label, Legend, Li, Link, Main, Map, Mark, Meta, Meter, Nav, Noscript, Object, Ol, Optgroup, Option, Output, P, Param, Picture, Pre, Progress, Q, Rp, Rt, Ruby, S, Samp, Script, Section, Select, Small, Source, Span, Strong, Style, Sub, Summary, Sup, Svg, Table, Tbody, Td, Template, Textarea, Tfoot, Th, Thead, Time, Title, Tr, Track, U, Ul, Var, Video, Wbr,
}
Html tag for Element and DomElement

Variants



A

Html tag



Abbr

Html tag



Address

Html tag



Article

Html tag



Aside

Html tag



Audio

Html tag



B

Html tag



Base

Html tag



Bdi

Html tag



Bdo

Html tag



Blockquote

Html tag



Body

Html tag



Br

Html tag



Button

Html tag



Caption

Html tag



Cite

Html tag



Code

Html tag



Col

Html tag



Colgroup

Html tag



Data

Html tag



Datalist

Html tag



Dd

Html tag



Del

Html tag



Details

Html tag



Dfn

Html tag



Dialog

Html tag



Div

Html tag



Dl

Html tag



Dt

Html tag



Em

Html tag



Embed

Html tag



Fieldset

Html tag



Figcaption

Html tag



Figure

Html tag



Footer

Html tag



Form

Html tag



H1

Html tag



H2

Html tag



H3

Html tag



H4

Html tag



H5

Html tag



H6

Html tag



Head

Html tag



Header

Html tag



Hr

Html tag



Html

Html tag



I

Html tag



Iframe

Html tag



Img

Html tag



Input

Html tag



Ins

Html tag



Kbd

Html tag



Label

Html tag



Legend

Html tag



Li

Html tag

Html tag



Main

Html tag



Map

Html tag



Mark

Html tag



Meta

Html tag



Meter

Html tag



Nav

Html tag



Noscript

Html tag



Object

Html tag



Ol

Html tag



Optgroup

Html tag



Option

Html tag



Output

Html tag



P

Html tag



Param

Html tag



Picture

Html tag



Pre

Html tag



Progress

Html tag



Q

Html tag



Rp

Html tag



Rt

Html tag



Ruby

Html tag



S

Html tag



Samp

Html tag



Script

Html tag



Section

Html tag



Select

Html tag



Small

Html tag



Html tag



Span

Html tag



Strong

Html tag



Style

Html tag



Sub

Html tag



Summary

Html tag



Sup

Html tag



Svg

Html tag



Table

Html tag



Tbody

Html tag



Td

Html tag



Template

Html tag



Textarea

Html tag



Tfoot

Html tag



Th

Html tag



Thead

Html tag



Time

Html tag



Title

Html tag



Tr

Html tag



Track

Html tag



U

Html tag



Ul

Html tag



Var

Html tag



Video

Html tag



Wbr

Html tag

Implementations

Source

impl Tag

pub fn is_void(&self) -> bool

An element which does not need a trailing slash when self-closing

Example: - <br> - Void element - <div/> - Not a void element